@@ -1,5 +1,5 @@
 package MyDB::Main;
 use base qw/DBIx::Class::Schema/;
-__PACKAGE__->load_classes(qw/Artist Cd Track/);
+__PACKAGE__->load_classes();
 
 1;
